==> trufflehog-3.81.5.tar.gz: trufflehog-3.81.5/pkg/detectors/clockworksms/clockworksms.go <==
package clockworksms

import (
	"context"
	regexp "github.com/wasilibs/go-re2"
	"net/http"
	"strings"

	"github.com/trufflesecurity/trufflehog/v3/pkg/common"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/detectorspb"
)

type Scanner struct {
	detectors.DefaultMultiPartCredentialProvider
}

// Ensure the Scanner satisfies the interface at compile time.
var _ detectors.Detector = (*Scanner)(nil)

var (
	client = common.SaneHttpClient()

	// Make sure that your group is surrounded in boundary characters such as below to reduce false positives.
	userKeyPat = regexp.MustCompile(detectors.PrefixRegex([]string{"clockwork", "textanywhere"}) + `\b([0-9]{5})\b`)
	tokenPat   = regexp.MustCompile(detectors.PrefixRegex([]string{"clockwork", "textanywhere"}) + `\b([0-9a-zA-Z]{24})\b`)
)

// Keywords are used for efficiently pre-filtering chunks.
// Use identifiers in the secret preferably, or the provider name.
func (s Scanner) Keywords() []string {
	return []string{"clockworksms", "textanywhere"}
}

// FromData will find and optionally verify Clockworksms secrets in a given set of bytes.
func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (results []detectors.Result, err error) {
	dataStr := string(data)

	userKeyMatches := userKeyPat.FindAllStringSubmatch(dataStr, -1)
	tokenMatches := tokenPat.FindAllStringSubmatch(dataStr, -1)

	for _, match := range userKeyMatches {
		if len(match) != 2 {
			continue
		}
		resMatch := strings.TrimSpace(match[1])

		for _, tokenMatch := range tokenMatches {
			if len(tokenMatch) != 2 {
				continue
			}
			tokenRes := strings.TrimSpace(tokenMatch[1])

			s1 := detectors.Result{
				DetectorType: detectorspb.DetectorType_ClockworkSMS,
				Raw:          []byte(resMatch),
				RawV2:        []byte(resMatch + tokenRes),
			}

			if verify {
				req, err := http.NewRequestWithContext(ctx, "GET", "https://api.textanywhere.com/API/v1.0/REST/status", nil)
				if err != nil {
					continue
				}
				req.Header.Add("user_key", resMatch)
				req.Header.Add("access_token", tokenRes)
				res, err := client.Do(req)
				if err == nil {
					defer res.Body.Close()
					if res.StatusCode >= 200 && res.StatusCode < 300 {
						s1.Verified = true
					}
				}
			}

			results = append(results, s1)
		}
	}

	return results, nil
}

func (s Scanner) Type() detectorspb.DetectorType {
	return detectorspb.DetectorType_ClockworkSMS
}

==> trufflehog-3.82.6.tar.gz: trufflehog-3.82.6/pkg/detectors/clockworksms/clockworksms.go <==
package clockworksms

import (
	"context"
	regexp "github.com/wasilibs/go-re2"
	"net/http"
	"strings"

	"github.com/trufflesecurity/trufflehog/v3/pkg/common"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/detectorspb"
)

type Scanner struct {
	detectors.DefaultMultiPartCredentialProvider
}

// Ensure the Scanner satisfies the interface at compile time.
var _ detectors.Detector = (*Scanner)(nil)

var (
	client = common.SaneHttpClient()

	// Make sure that your group is surrounded in boundary characters such as below to reduce false positives.
	userKeyPat = regexp.MustCompile(detectors.PrefixRegex([]string{"clockwork", "textanywhere"}) + `\b([0-9]{5})\b`)
	tokenPat   = regexp.MustCompile(detectors.PrefixRegex([]string{"clockwork", "textanywhere"}) + `\b([0-9a-zA-Z]{24})\b`)
)

// Keywords are used for efficiently pre-filtering chunks.
// Use identifiers in the secret preferably, or the provider name.
func (s Scanner) Keywords() []string {
	return []string{"clockworksms", "textanywhere"}
}

// FromData will find and optionally verify Clockworksms secrets in a given set of bytes.
func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (results []detectors.Result, err error) {
	dataStr := string(data)

	userKeyMatches := userKeyPat.FindAllStringSubmatch(dataStr, -1)
	tokenMatches := tokenPat.FindAllStringSubmatch(dataStr, -1)

	for _, match := range userKeyMatches {
		if len(match) != 2 {
			continue
		}
		resMatch := strings.TrimSpace(match[1])

		for _, tokenMatch := range tokenMatches {
			if len(tokenMatch) != 2 {
				continue
			}
			tokenRes := strings.TrimSpace(tokenMatch[1])

			s1 := detectors.Result{
				DetectorType: detectorspb.DetectorType_ClockworkSMS,
				Raw:          []byte(resMatch),
				RawV2:        []byte(resMatch + tokenRes),
			}

			if verify {
				req, err := http.NewRequestWithContext(ctx, "GET", "https://api.textanywhere.com/API/v1.0/REST/status", nil)
				if err != nil {
					continue
				}
				req.Header.Add("user_key", resMatch)
				req.Header.Add("access_token", tokenRes)
				res, err := client.Do(req)
				if err == nil {
					defer res.Body.Close()
					if res.StatusCode >= 200 && res.StatusCode < 300 {
						s1.Verified = true
					}
				}
			}

			results = append(results, s1)
		}
	}

	return results, nil
}

func (s Scanner) Type() detectorspb.DetectorType {
	return detectorspb.DetectorType_ClockworkSMS
}

func (s Scanner) Description() string {
	return "Clockwork SMS is a service used for sending SMS messages. User keys and access tokens can be used to authenticate and send messages via the Clockwork SMS API."
}
